/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Effacer"

, "Reply"
: "Répondre"

, "Reply To All"
: "Répondre à tous"

, "Forward"
: "Transférer"

, "Print Message"
: "Imprimer le message"

, "Print Preview"
: "Aperçu avant impression"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "Absence"
 ,"Absences"

]
, "Account, Accounts"
: [
  "Compte"
 ,"Comptes"

]
, "Account Name"
: "Nom du compte"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Adresse électronique"

, "User Name (From)"
: "Nom affiché (expéditeur)"

, "Organization"
: "Organisation"

, "Signature position"
: "Position de la signature"

, "Above the quote"
: "Au-dessus de la citation"

, "Below the quote"
: "Sous la citation"

, "IMAP"
: "IMAP"

, "Host"
: "Hôte"

, "Port (Default: 143 / SSL: 993)"
: "Port (Défaut: 143 / SSL: 993)"

, "Secure Connection"
: "Connexion sécurisée"

, "None"
: "Aucun"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Nom d'utilisateur"

, "Password"
: "Mot de passe"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Port (Défaut: 25)"

, "Authentication"
: "Authentification"

, "Login"
: "Login"

, "Plain"
: "Texte simple"

, "Username (optional)"
: "Nom d'utilisateur (facultatif)"

, "Password (optional)"
: "Mot de passe (facultatif)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Sieve"

, "Port (Default: 2000)"
: "Port (par défaut : 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Autre"

, "Sent Folder Name"
: "Nom du dossier \"Sent\""

, "Trash Folder Name"
: "Nom du dossier \"Trash\""

, "Drafts Folder Name"
: "Dossier des Brouillons"

, "Templates Folder Name"
: "Dossier des Modèles"

, "Display Format"
: "Format d'affichage"

, "HTML"
: "HTML"

, "Plain Text"
: "Texte simple"

, "Depending on content type (experimental)"
: "Dépendant du type de contenu (expérimental)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Écrire"

, "Toggle highlighting"
: "Important"

, "Mark read/unread"
: "Marquer comme lu / non-lu"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Ajouter un compte"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "P.J."

, "Flags"
: "Marqueurs"

, "Subject"
: "Sujet"

, "From (Email)"
: "De (adresse)"

, "From (Name)"
: "Expéditeur"

, "Sender"
: "Envoyé par"

, "To"
: "Destinataire"

, "Sent"
: "Envoyés"

, "Received"
: "Reçu"

, "Folder, Folders"
: [
  "un dossier"
 ,"des dossiers"

]
, "Size"
: "Taille"

, "Answered"
: "Répondu"

, "Forwarded"
: "Transféré"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: "Envoyer un accusé de réception"

, "Do you want to send a reading confirmation message?"
: "Voulez vous envoyer un accusé de réception ?"

, "Empty Folder"
: "Vider le dossier"

, "Add Folder"
: "Créer un dossier"

, "New {0}"
: "Nouveau {0}"

, "Please enter the name of the new {0}:"
: "Saisissez le nom du nouveau {0} :"

, "No {0} added"
: "aucun(e) {0} ajouté(e)"

, "You have to supply a {0} name!"
: "Vous devez mettre un nom de {0} !"

, "Please wait"
: "Veuillez patienter"

, "Creating {0}..."
: "Création de {0}..."

, "Edit Account"
: "Éditer compte"

, "Edit Vacation Message"
: "Message d’absence"

, "Edit Filter Rules"
: "Modifier les règles de filtrage"

, "Notifications"
: ""

, "Mark Folder as read"
: "Marquer le dossier comme lu"

, "Update Folder List"
: "Mettre à jour la liste des dossiers"

, "Message not available."
: "Message indisponible"

, "Cancel"
: "Annuler"

, "Ok"
: "Ok"

, "Folders of account {0}"
: "Dossiers du compte {0}"

, "Folders of all accounts"
: "Dossiers de tous les comptes"

, "Compose email"
: "Écrire un message"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "De"

, "Add"
: "Nouveau dossier"

, "Add contact to addressbook"
: "Ajouter au carnet d'adresse"

, "Date"
: "Date"

, "Show or hide header information"
: "Afficher/Masquer l'entête de message"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(nouveau message)"

, "Select recipients for \"{0}\""
: "Sélectionner le destinataire pour \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Filtre destinataire"

, "All recipients"
: "Tous les destinataires"

, "\"{0}\" recipients"
: "\"{0}\" destinataires"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Message d'absence pour {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Monter"

, "Move down"
: "Descendre"

, "Enable"
: "Activer"

, "Disable"
: "Désactiver"

, "ID"
: "ID"

, "Conditions"
: "Conditions"

, "Action"
: "Action"

, "Keep a copy"
: ""

, "is greater than"
: "est supérieur à"

, "is less than"
: "est inférieur à"

, "Header \"{0}\" contains \"{1}\""
: "L'entete \"{0}\" contient \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "En-tête \"{0}\" correspond à \"{1}\""

, "Sieve Filter Rules"
: "Enregistrer les règles Sieve"

, "Sieve Filter Rules for {0}"
: "Règles de filtrage Sieve pour {0}"

, "From (Email and Name)"
: "De (adresse et nom)"

, "To (Email)"
: "Destinataire (adresse)"

, "To (Email CC)"
: ""

, "Header contains"
: "L'entête contient"

, "Header name"
: "Nom d'en-tête"

, "Header value"
: "Header value"

, "Header regex"
: "Header regex"

, "Edit Filter Rule"
: "Éditer la règle de filtrage"

, "Apply filter if"
: ""

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Effectuer cette action :"

, "Move mail to folder"
: "Déplacer le message dans le dossier"

, "Redirect mail to address"
: "Rediriger le message vers l'adresse"

, "Reject mail with this text"
: "Rejeter le message avec ce message"

, "Discard mail"
: "Refuser le message"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Garder le message"

, "General"
: "Général"

, "Advanced"
: "Avancé"

, "Only send all X days to the same sender"
: "Attendre X jours avant de renvoyer l'alerte à un même contact."

, "Incoming mails will be answered with this text:"
: "La réponse aux messages reçus sera :"

, "Status"
: "Statut"

, "I am available (vacation message disabled)"
: "Je suis disponible (message d'absence désactivé)"

, "I am not available (vacation message enabled)"
: "Je ne suis pas disponible (message d'absence activé)"

, "Start Date"
: "Date de début"

, "Set vacation start date ..."
: "Date de début d'absence"

, "End Date"
: "Date de fin"

, "Set vacation end date ..."
: "Date de fin d'absence"

, "Representative #1"
: "Réprésentant #1"

, "Choose first Representative ..."
: "Sélectionner le premier représentant"

, "Representative #2"
: "Réprésentant #2"

, "Choose second Representative ..."
: "Sélectionner le second représentant"

, "Message Template"
: "Modèle de message"

, "Choose Template ..."
: "Choisir le modèle ..."

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Message"
 ,"Messages"

]
, "Subject/From"
: "Sujet/De"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: "Boîte de réception"

, "Drafts"
: "Brouillons"

, "Templates"
: "Modèles"

, "Junk"
: "Indésirables"

, "Trash"
: "Corbeille"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "liste d'enregistrement"
 ,"listes d'enregistrements"

]
, "Rule, Rules"
: [
  "Règle"
 ,"Règles"

]
, "Flag, Flags"
: [
  "Indicateur"
 ,"Indicateurs"

]
, "Flag list, Flag lists"
: [
  "Liste d'indicateurs"
 ,"Listes d'indicateurs"

]
, "Total Messages:"
: "Total des messages :"

, "Unread Messages:"
: "Messages non lus :"

, "Name on Server:"
: "Nom sur le serveur :"

, "Last update:"
: "Dernière modification"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "{0} message non lu"
 ,"{0} messages non lus"

]
, "New Mail"
: "Nouveau message"

, "Email"
: "Messagerie"

, "Active Vacation Message"
: "Message d'absence actuel"

, "Email account \"{0}\" has an active vacation message."
: "L'alerte absence est activée sur le compte messagerie \"{0}\"."

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Nouveaux messages"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Vous avez {0} nouveau(x) message(s) dans le dossier {1} ({2})."

, "IMAP Credentials for {0}"
: "Authentification IMAP de {0}"

, "Credentials"
: "Identifiants"

, "IMAP Error"
: "Erreur IMAP"

, "No connection to IMAP server."
: "Pas de connexion au serveur IMAP."

, "IMAP Credentials Error"
: "Erreur dans les identifiants IMAP"

, "Your email credentials are wrong. Please contact your administrator"
: "Vos identifiants sont invalides. Merci de contacter votre administrateur."

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "La structure des dossiers a été modifiée par un autre programme et doit être mise à jour."

, "SMTP Error"
: "Erreur SMTP"

, "No connection to SMTP server."
: "Pas de connexion au serveur SMTP."

, "Sieve Error"
: "Erreur Sieve"

, "No connection to Sieve server."
: "Pas de connexion au serveur Sieve."

, "Save Sieve Script Error"
: "Enregistrer les erreurs de script Sieve"

, "Could not save script on Sieve server."
: "Impossible d'enregistrer le script Sieve"

, "Add as \"To\""
: "Ajouter au(x) destinataire(s)"

, "Add as \"Cc\""
: "Ajouter en copie conforme"

, "Add as \"Bcc\""
: "Ajouter en copie cachée"

, "Remove from recipients"
: "Supprimer des destinataires"

, "Loading Mail Addresses"
: "Chargement des adresses électroniques"

, "Click here to set To/CC/BCC."
: "Cliquer ici pour définir le type de destinataire"

, "To:"
: "À :"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "Retirer"

, "Send"
: "Envoyer"

, "Search Recipients"
: "Rechercher dans les destinataires"

, "Save As Draft"
: "Sauvegarder le brouillon"

, "Save As Template"
: "Garder le modèle"

, "Reading Confirmation"
: "Accusé de réception"

, "Activate this toggle button to receive a reading confirmation."
: "Demander un accusé de réception pour ce message"

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Rechercher et ajouter des destinataires à partir du carnet d'adresses."

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "TR:"

, "{0} Message"
: "{0} messages"

, "Failed"
: "Échoué"

, "{0} account setting empty."
: "{0} paramètre de compte vide."

, "Files are still uploading."
: "Fichiers en cours de télééchargement"

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "Le {0}, {1} a écrit"

, "Original message"
: "message original"

, "Compose email:"
: "Écrire un message :"

, "Convert to formated text"
: ""

, "Body"
: "Corps"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "Pas de sujet"

, "Do you really want to send a message with an empty subject?"
: "Confirmez vous l'envoi d'un message sans sujet ?"

, "No recipients set."
: "Pas de destinataire"

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Tous les boîtes de réception"

, "Default Email Account"
: "Compte messagerie par défaut"

, "The default email account to use when sending mails."
: "Compte par défaut pour l'envoi des messages."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Intervalle de mise à jour des messages"

, "How often should Felamimail check for new Emails (in minutes)."
: "Felamimail récupèrera les nouveaux messages automatiquement (toutes les x minutes)."

, "Use for mailto links"
: ""

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Utiliser dans les Notes"

, "Save Note default Value."
: "Sauvegarde dans les Notes par défaut"

, "Confirm Delete"
: "Confirmer la suppression"

, "Show confirmation dialog when deleting mails."
: "Demander confirmation avant de supprimer des messages."

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "Message d'absence personnalisé"

, "User is allowed to set custom vacation message for system account"
: "L'utilisateur est autorisé à changer son message d'absence"

, "Cache email body"
: "Mettre en cache le corps du message"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Si la connexion au serveur IMAP est lente, il est recommandé de mettre le corps du message en cache"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: "Accusé de réception :"

, "Your message:"
: "Votre message :"

, "Received on"
: "Reçu le"

, "Was read by:"
: "Lu par :"

, "on"
: "le"

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Réponse \"Je suis absent\" de %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: "Erreur : %s"

, "Could not send message"
: "Impossible d'envoyer le message"

, "My Mail Download Links"
: ""

, "Seen"
: "Vu"

, "Deleted"
: "Supprimé"

, "Draft"
: "Brouillon"

, "Flagged"
: "Marqué"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Tous les boîtes de réception de mes comptes"

, "All unread mail"
: "Tous les messages non lus"

, "All unread mail of my email accounts"
: "Tous les messages non lus de mes comptes"

, "All highlighted mail"
: "Tous les messages importants"

, "All highlighted mail of my email accounts"
: "Tous les messages importants de mes comptes"

, "All drafts"
: "Tous les brouillons"

, "All mails with the draft flag"
: "Tous les brouillons"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "Gérer les comptes messagerie."

, "Edit and delete email accounts"
: "Modifier ou supprimer les comptes messagerie"

, "Add email accounts"
: "Ajouter des comptes messagerie"

, "Create new email accounts"
: "Créer de nouveaux comptes messagerie"

, "Vacation"
: "Absence"

, "Account"
: "Compte"

, "Folder"
: "un dossier"

, "Message"
: "Message"

, "record list"
: "liste d'enregistrement"

, "Rule"
: "Règle"

, "Flag"
: "Indicateur"

, "Flag list"
: "Liste d'indicateurs"

, "{0} unread message"
: "{0} message non lu"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
